@@ -7,6 +7,8 @@ from PyQt4 import QtGui
 import Image
 import code
 
+CURRENTVERSION = "0.2.6"
+
 class MainWindow(QtGui.QMainWindow):
     def __init__(self):
         
@@ -17,7 +19,7 @@ class MainWindow(QtGui.QMainWindow):
 
         #Initial Settings
         self.resize(800,480)
-        self.setWindowTitle('London Tube Map 0.2.5')
+        self.setWindowTitle('London Tube Map 0.2.6')
         
         #Open Image
         self.ChargerScene()
@@ -25,7 +27,6 @@ class MainWindow(QtGui.QMainWindow):
         ################
         #Menu Bar#
         ################
-
         #Fullscreen
         fullsc = QtGui.QAction('Fullscreen', self)
         fullsc.setShortcut('Ctrl+X')
@@ -34,26 +35,26 @@ class MainWindow(QtGui.QMainWindow):
         #About
         abt = QtGui.QAction('About', self)
         fullsc.setShortcut('Ctrl+A')
-        self.connect(abt, QtCore.SIGNAL('triggered()'), self.about)
+        self.connect(abt, QtCore.SIGNAL('triggered()'), self.showAbout)
+        
+        #Alternative 
+        altImg = QtGui.QAction('Alternative ', self)
+        altImg.setShortcut('Ctrl+I')
+        self.connect(altImg, QtCore.SIGNAL('triggered()'), self.alternative)
         
         #Connect to Menu Bar
         menubar = self.menuBar()
-        file = menubar.addMenu('&File')
+        file = menubar.addMenu('&Fichier')
         file.addAction(fullsc)
+        file.addAction(altImg)
         file.addAction(abt)
         
-        #Functions for items in menu bar
-    def fullscreen(self):
-        if not self.fullScreen :
-            self.showFullScreen()
-        else:
-            self.showNormal()
-
-        self.fullScreen = not (self.fullScreen)    
         
-    def about(self):
-        print "To be added later"
-
+        #About page
+    def showAbout(self):
+        aboutString = "London Tube Map: v" + CURRENTVERSION + "\nAmir Bendjazia (benjezzy@gmail.com)\nMaemo Forums: El Amir, \nTwitter: benjezzy \nMany thanks to everyone who helped! "
+        QtGui.QMessageBox.information(self, "About Tfl App", aboutString)
+        
     def ChargerScene(self):
         #Load image
         objImg = QtGui.QImage("/opt/ltm/images/map.png")
